NAME

Text::JSCalendar::TimeZones - autogenerated timezone data for Text::JSCalendar

SYNOPSIS

 *** WARNING: DO NOT EDIT ***

 This file is generated by utils/GenerateTimeZoneModule.pl

./utils/GenerateTimeZoneModule.pl htdocs/ajaxui/build/fastmail/timezones-raw.js > modules/Net/CalDAVTalk/TimeZones.pm

Generated: Thu Aug 13 02:55:03 2015

SUBROUTINES/METHODS

$Class->GetTimeZone(%Args)

Args:

TZID - zone name
StandardTzOffsetTo - offset

Pick the matching timezone with the highest population size to the offset if the zone name isn't known.

Returns a DateTime::TimeZone object

$Class->GetVTimeZone($TimeZone)

Returns a Data::ICal::TimeZone object for the named zone

LICENSE AND COPYRIGHT

Copyright 2019-2026 Fastmail Pty Ltd.

This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself; that is, either the GNU General Public License as published by the Free Software Foundation (version 1, or at your option any later version), or the Artistic License.

See http://dev.perl.org/licenses/ and the LICENSE file included with this distribution for more information.